"road.map" <-
function () 
{
    cat(paste(rep("=", options()$width), collapse = ""), "\n\n")
    cat("What you typically want to do is the following sequence:\n\n")
    cat("1) Read in one or more track(s):\n\n")
    cat("   Done via basic R-functions like 'read.table' or 'read.csv'\n")
    cat("   For instance if your track file is organized like:\n\n")
    cat("   day month year  obsLon obsLat obsSst\n")
    cat("    10     9 2002  198.04  23.09   30.6\n")
    cat("    11     9 2002  198.11  50.50   30.7\n")
    cat("    12     9 2002  197.65  45.50   30.6\n")
    cat("                < and so on >\n\n")
    cat("   the command:\n\n")
    cat("      track1 <- read.table(<filename>, head=TRUE)\n\n")
    cat("   should read the data into a data frame named 'track1'.\n")
    cat("   Notice that if several tracks are in the same region and\n")
    cat("   time period it is better to read all of them before step 2),\n")
    cat("   because then one SST-field covering all tracks can be \n")
    cat("   constructed.\n\n")
    dummy <- readline("2) Obtain a corresponding SST-field: (press <return>)\n\n")
    cat("   A simple server has been set up to extract SST-fields that\n")
    cat("   covers a track (or a set of tracks) in simple way from\n")
    cat("   within R. To use this source type a command similar to:\n\n")
    cat("      sst.path <- get.sst.from.server(track1)\n\n")
    cat("   Notice 'track1' can be replaced by a list of tracks like:\n\n")
    cat("      sst.path <- get.sst.from.server(list(track1, track2))\n\n")
    cat("   to obtain an SST-field covering a set of tracks.\n\n")
    cat("   The path returned from the function is where all the SST\n")
    cat("   files are saved (useful in step 3)). To use a different\n")
    cat("   SST-source please see documentation for the function\n")
    cat("   'write.sst.field'.\n\n")
    dummy <- readline("3) Smooth the SST-field and save it in suitable format: (press <return>)\n\n")
    cat("   A function is supplied to automate the process of reading\n")
    cat("   smoothing, and saving the SST-data in the right format. Its\n")
    cat("   basic use is:\n\n")
    cat("      sst.file <- write.sst.field(sst.path)\n\n")
    cat("   but it comes with a lot of options to adjust degree of \n")
    cat("   smoothing and resolution of field representation. Please \n")
    cat("   consult the documentation to see all the details.\n\n")
    cat("   The filename returned (including absolute path) is where\n")
    cat("   the smooth representation of the SST-field is saved.\n\n")
    dummy <- readline("4) Reconstruct the track(s): (press <return>)\n\n")
    cat("   To old users of the KFtrack package running this step\n")
    cat("   should be very familiar. To apply the default full model to\n")
    cat("   a track simply type: \n\n")
    cat("      fit <- kfsst(track1, sst.file)\n\n")
    cat("   It is possible and in some cases necessary to customize the\n")
    cat("   full model, for instance by choosing a simpler variance\n")
    cat("   structure, or leaving out a bias term. For details on these\n")
    cat("   and other options, please see the documentation (?kfsst).\n\n")
    dummy <- readline("5) Investigate the fitted track(s): (press <return>)\n\n")
    cat("   A basic plotting command is associated with the object\n")
    cat("   returned from the function 'kfsst', hence to see a\n")
    cat("   plotted representation of the fit type: \n\n")
    cat("      plot(fit)\n\n")
    cat("   Often the raw geo locations are so poor that you may wish\n")
    cat("   to leave them out of the plot to better zoom in on the\n")
    cat("   reconstructed track. Also you may wish to get a visual\n")
    cat("   representation of the uncertainties. Invoking the plot\n")
    cat("   command with the following options will achieve that:\n\n")
    cat("      plot(fit, points=FALSE, ci=TRUE)\n\n")
    cat("   It is also possible to have the track displayed on a map,\n")
    cat("   but it requires the free software GMT to be installed also.\n")
    cat("   Read all about it in the documentation (?plot.kfsst).\n\n")
    cat("   Besides the supplied plotting method it is possible to use\n")
    cat("   the rich facilities in R to explore the track and the\n")
    cat("   estimated model parameters. Everything needed from the\n")
    cat("   estimated track is available via the returned object 'fit'.\n")
    cat("   Try typing the name of the fitted object:\n\n")
    cat("      fit\n\n")
    cat("   A list of the sub-objects in 'fit' should now be displayed\n")
    cat("   Along with a summary of the fit. To access a sub-object,\n")
    cat("   for instance the negative log likelihood value type: \n\n")
    cat("      fit$nlogL\n\n")
    cat("   Notice the use of '$' as sub-object operator.\n\n")
    cat(paste(rep("=", options()$width), collapse = ""), "\n\n")
}
